@@ -33,22 +33,25 @@ from fsm_pull.connection import Connection
 from fsm_pull.protobuf.records_pb2 import Call, Turn, Utterance
 
 
-def convert_date(date_string: str, timezone="Asia/Kolkata") -> str:
+def convert_date(date_string: str, trailing=False, timezone="Asia/Kolkata") -> str:
     if not isinstance(date_string, str):
         raise ValueError("Date should be ddmmyyyy format")
 
     if date_string != "now" and len(date_string) != 8:
         raise ValueError("Date should be ddmmyyyy format")
 
-    current_time = datetime.now() + timedelta(days=1)
-    current_time = current_time.replace(tzinfo=pytz.timezone(timezone))
+    current_time = datetime.now()
+    current_time = current_time.replace(hour=23, minute=59, tzinfo=pytz.timezone(timezone))
     start_limit = datetime(2016, 1, 6).replace(tzinfo=pytz.timezone(timezone))
 
     if date_string == "now":
         return current_time.isoformat()
     else:
         given_date = datetime.strptime(date_string, "%d%m%Y")
-        given_date = given_date.replace(tzinfo=pytz.timezone(timezone))
+        if trailing:
+            given_date = given_date.replace(hour=23, minute=59, tzinfo=pytz.timezone(timezone))
+        else:
+            given_date = given_date.replace(tzinfo=pytz.timezone(timezone))
 
         if start_limit <= given_date <= current_time:
             return given_date.isoformat()
@@ -79,7 +82,7 @@ def get_call_list(
     subtesting=False
 ):
     start = convert_date(start)
-    end = convert_date(end)
+    end = convert_date(end, trailing=True)
 
     new_connection = Connection(org_id)
     proc_start_time = time.time()
