@@ -182,15 +182,20 @@ def prediction_from_plute(prediction):
 
 def prediction_from_dialogy(prediction):
     try:
-        intent = prediction.get("intents")[0]
+        if "intents" in prediction:
+            intent = prediction.get("intents")[0]
+        elif "name" in prediction and ("slot" in prediction or "slots" in prediction):
+            intent = prediction
+
+        slot_key = "slot" if "slot" in intent else "slots"
         prediction = {
             "name": intent.get("name"),
             "score": intent.get("score"),
-            "slot": []
+            "slots": []
         }
         entities_from_all_slots = []
 
-        for slot in intent.get("slots", []):
+        for slot in intent.get(slot_key, []):
             entities = [{
                 "text": entity.get("body"),
                 "type": entity.get("type"),
